"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const repo_cloc_diff_functions_1 = require("./repo-cloc-diff.functions");
// #copilot - good part of the boilerplate of the test has been generated by copilot
describe('commitDiffPairs', () => {
    it('should return an object with pairs of most recent and least recent commits for each month', () => {
        const commitsByMonth = {
            '2021-03': [{ sha: 'def', date: new Date('2021-03-01'), author: 'author1' }],
            '2021-02': [
                { sha: 'abc', date: new Date('2021-02-15'), author: 'author3' },
                { sha: '789', date: new Date('2021-02-01'), author: 'author1' },
            ],
            '2021-01': [
                { sha: '456', date: new Date('2021-01-15'), author: 'author2' },
                { sha: '123', date: new Date('2021-01-01'), author: 'author1' },
            ],
        };
        const expectedPairs = {
            '2021-03': [
                { sha: 'def', date: new Date('2021-03-01'), author: 'author1' },
                { sha: 'abc', date: new Date('2021-02-15'), author: 'author3' },
            ],
            '2021-02': [
                { sha: 'abc', date: new Date('2021-02-15'), author: 'author3' },
                { sha: '456', date: new Date('2021-01-15'), author: 'author2' },
            ],
            '2021-01': [
                { sha: '456', date: new Date('2021-01-15'), author: 'author2' },
                { sha: '123', date: new Date('2021-01-01'), author: 'author1' },
            ],
        };
        const pairs = (0, repo_cloc_diff_functions_1.commitMonthlyPairs)(commitsByMonth);
        (0, chai_1.expect)(pairs).deep.equal(expectedPairs);
    });
    it('should return an object with null pairs for months with no commits', () => {
        const commitsByMonth = {
            '2021-03': [{ sha: 'def', date: new Date('2021-03-01'), author: 'author1' }],
            '2021-02': [],
            '2021-01': [
                { sha: '456', date: new Date('2021-01-15'), author: 'author2' },
                { sha: '123', date: new Date('2021-01-01'), author: 'author1' },
            ],
        };
        const expectedPairs = {
            '2021-03': [
                { sha: 'def', date: new Date('2021-03-01'), author: 'author1' },
                { sha: '456', date: new Date('2021-01-15'), author: 'author2' },
            ],
            '2021-02': null,
            '2021-01': [
                { sha: '456', date: new Date('2021-01-15'), author: 'author2' },
                { sha: '123', date: new Date('2021-01-01'), author: 'author1' },
            ],
        };
        const pairs = (0, repo_cloc_diff_functions_1.commitMonthlyPairs)(commitsByMonth);
        (0, chai_1.expect)(pairs).deep.equal(expectedPairs);
    });
    it('should return an object with null pairs for the first month with only one commit', () => {
        const commitsByMonth = {
            '2021-03': [{ sha: 'def', date: new Date('2021-03-01'), author: 'author1' }],
            '2021-02': [{ sha: '456', date: new Date('2021-02-01'), author: 'author2' }],
            '2021-01': [{ sha: '123', date: new Date('2021-01-01'), author: 'author1' }],
        };
        const expectedPairs = {
            '2021-03': [
                { sha: 'def', date: new Date('2021-03-01'), author: 'author1' },
                { sha: '456', date: new Date('2021-02-01'), author: 'author2' },
            ],
            '2021-02': [
                { sha: '456', date: new Date('2021-02-01'), author: 'author2' },
                { sha: '123', date: new Date('2021-01-01'), author: 'author1' },
            ],
            '2021-01': null,
        };
        const pairs = (0, repo_cloc_diff_functions_1.commitMonthlyPairs)(commitsByMonth);
        (0, chai_1.expect)(pairs).deep.equal(expectedPairs);
    });
    it('works even if the order of the commits is not from the most recent to the least recent', () => {
        const commitsByMonth = {
            '2021-03': [{ sha: 'def', date: new Date('2021-03-01'), author: 'author1' }],
            '2021-02': [
                // in this case, the order of the commits is not from the least recent to the most recent
                { sha: '789', date: new Date('2021-02-01'), author: 'author1' },
                { sha: 'abc', date: new Date('2021-02-15'), author: 'author3' },
            ],
            '2021-01': [
                { sha: '456', date: new Date('2021-01-15'), author: 'author2' },
                { sha: '123', date: new Date('2021-01-01'), author: 'author1' },
            ],
        };
        const expectedPairs = {
            '2021-03': [
                { sha: 'def', date: new Date('2021-03-01'), author: 'author1' },
                { sha: 'abc', date: new Date('2021-02-15'), author: 'author3' },
            ],
            '2021-02': [
                { sha: 'abc', date: new Date('2021-02-15'), author: 'author3' },
                { sha: '456', date: new Date('2021-01-15'), author: 'author2' },
            ],
            '2021-01': [
                { sha: '456', date: new Date('2021-01-15'), author: 'author2' },
                { sha: '123', date: new Date('2021-01-01'), author: 'author1' },
            ],
        };
        const pairs = (0, repo_cloc_diff_functions_1.commitMonthlyPairs)(commitsByMonth);
        (0, chai_1.expect)(pairs).deep.equal(expectedPairs);
    });
    it('works even if the order of the keys of the dictionary is not from the most recent to the least recent', () => {
        const commitsByMonth = {
            // in this case, the olderst month is inserted first
            '2021-01': [
                { sha: '456', date: new Date('2021-01-15'), author: 'author2' },
                { sha: '123', date: new Date('2021-01-01'), author: 'author1' },
            ],
            '2021-03': [{ sha: 'def', date: new Date('2021-03-01'), author: 'author1' }],
            '2021-02': [
                // in this case, the order of the commits is not from the least recent to the most recent
                { sha: '789', date: new Date('2021-02-01'), author: 'author1' },
                { sha: 'abc', date: new Date('2021-02-15'), author: 'author3' },
            ],
        };
        const expectedPairs = {
            '2021-03': [
                { sha: 'def', date: new Date('2021-03-01'), author: 'author1' },
                { sha: 'abc', date: new Date('2021-02-15'), author: 'author3' },
            ],
            '2021-02': [
                { sha: 'abc', date: new Date('2021-02-15'), author: 'author3' },
                { sha: '456', date: new Date('2021-01-15'), author: 'author2' },
            ],
            '2021-01': [
                { sha: '456', date: new Date('2021-01-15'), author: 'author2' },
                { sha: '123', date: new Date('2021-01-01'), author: 'author1' },
            ],
        };
        const pairs = (0, repo_cloc_diff_functions_1.commitMonthlyPairs)(commitsByMonth);
        (0, chai_1.expect)(pairs).deep.equal(expectedPairs);
    });
});
describe('reposCommitsPairsDiff', () => {
    it(`should return an array of objects with name of the repo and an array of pairs of most recent and least recent commits 
    for each month`, () => {
        const commitsByMonthRepo_1 = {
            '2021-03': [{ sha: 'def_1', date: new Date('2021-03-01'), author: 'author1' }],
            '2021-02': [
                { sha: 'abc_1', date: new Date('2021-02-15'), author: 'author3' },
                { sha: '789_1', date: new Date('2021-02-01'), author: 'author1' },
            ],
            '2021-01': [
                { sha: '456_1', date: new Date('2021-01-15'), author: 'author2' },
                { sha: '123_1', date: new Date('2021-01-01'), author: 'author1' },
            ],
        };
        const commitsByMonthRepo_2 = {
            '2021-03': [{ sha: 'def_2', date: new Date('2021-03-01'), author: 'author1' }],
            '2021-02': [
                { sha: 'abc_2', date: new Date('2021-02-15'), author: 'author3' },
                { sha: '789_2', date: new Date('2021-02-01'), author: 'author1' },
            ],
            '2021-01': [
                { sha: '456_2', date: new Date('2021-01-15'), author: 'author2' },
                { sha: '123_2', date: new Date('2021-01-01'), author: 'author1' },
            ],
        };
        const repoDictWithCommits = {
            repo_1: commitsByMonthRepo_1,
            repo_2: commitsByMonthRepo_2,
        };
        const expectedPairs_repo_1 = {
            '2021-03': [
                { sha: 'def_1', date: new Date('2021-03-01'), author: 'author1' },
                { sha: 'abc_1', date: new Date('2021-02-15'), author: 'author3' },
            ],
            '2021-02': [
                { sha: 'abc_1', date: new Date('2021-02-15'), author: 'author3' },
                { sha: '456_1', date: new Date('2021-01-15'), author: 'author2' },
            ],
            '2021-01': [
                { sha: '456_1', date: new Date('2021-01-15'), author: 'author2' },
                { sha: '123_1', date: new Date('2021-01-01'), author: 'author1' },
            ],
        };
        const expectedPairs_repo_2 = {
            '2021-03': [
                { sha: 'def_2', date: new Date('2021-03-01'), author: 'author1' },
                { sha: 'abc_2', date: new Date('2021-02-15'), author: 'author3' },
            ],
            '2021-02': [
                { sha: 'abc_2', date: new Date('2021-02-15'), author: 'author3' },
                { sha: '456_2', date: new Date('2021-01-15'), author: 'author2' },
            ],
            '2021-01': [
                { sha: '456_2', date: new Date('2021-01-15'), author: 'author2' },
                { sha: '123_2', date: new Date('2021-01-01'), author: 'author1' },
            ],
        };
        const expectedRepoDictPairs = [
            { repoPath: 'repo_1', commitPairs: expectedPairs_repo_1 },
            { repoPath: 'repo_2', commitPairs: expectedPairs_repo_2 },
        ];
        const repoDictPairs = (0, repo_cloc_diff_functions_1.commitsMonthlyPairsForRepos)(repoDictWithCommits);
        (0, chai_1.expect)(repoDictPairs).deep.equal(expectedRepoDictPairs);
    });
});
//# sourceMappingURL=repo-cloc-diff.functions.spec.js.map